package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.diagbot.dto.*;
import com.diagbot.entity.*;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.enums.ModeIdEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.MedQcresultCasesServiceImpl;
import com.diagbot.service.impl.QcRuleWarnServiceImpl;
import com.diagbot.service.impl.QcresultDetailServiceImpl;
import com.diagbot.service.impl.QcresultInfoServiceImpl;
import com.diagbot.util.*;
import com.diagbot.vo.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2020/4/13 17:22
 */
@Component
public class QcresultInfoFacade extends QcresultInfoServiceImpl {
    @Autowired
    @Qualifier("qcresultDetailServiceImpl")
    private QcresultDetailServiceImpl qcresultDetailServiceImpl;
    @Autowired
    @Qualifier("qcRuleWarnServiceImpl")
    private QcRuleWarnServiceImpl qcRuleWarnServiceImpl;
    @Autowired
    private AlgorithmFacade algorithmFacade;
    @Autowired
    private BehospitalInfoFacade behospitalInfoFacade;
    @Autowired
    private ReadProperties readProperties;
    @Autowired
    private QcCasesEntryFacade qcCasesEntryFacade;
    @Autowired
    private MedCheckInfoFacade medCheckInfoFacade;
    @Autowired
    private QcresultDetailFacade qcresultDetailFacade;
    @Autowired
    @Qualifier("medQcresultCasesServiceImpl")
    private MedQcresultCasesServiceImpl medQcresultCasesService;

    private TZDBConn tzDBConn = new TZDBConn();


    /**
     * 发送规则信息到医生工作站
     *
     * @param qcRuleWarnVO
     * @return Boolean
     */
    public Boolean sendRuleWarn(QcRuleWarnVO qcRuleWarnVO) {
        //入参验证
        if (StringUtil.isBlank(qcRuleWarnVO.getBehospitalCode())) {
            throw new CommonException(CommonErrorCode.PARAM_IS_NULL, "病历id不能为空！");
        }
        if (null == qcRuleWarnVO.getMsg()) {
            throw new CommonException(CommonErrorCode.PARAM_IS_NULL, "操作条目不能为空！");
        }
        Long hospitalId = Long.valueOf(SysUserUtils.getCurrentHospitalID());
        Date now = DateUtil.now();
        BehospitalInfo behospitalInfo
                = behospitalInfoFacade.getOne(
                new QueryWrapper<BehospitalInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .eq("behospital_code", qcRuleWarnVO.getBehospitalCode()));
        if (null == behospitalInfo) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "该医院下该病历号不存在！");
        }
        String doctorId = behospitalInfo.getDoctorId();
        if (StringUtil.isBlank(doctorId) || doctorId.equals("-")) {
            doctorId = "0";
        }
        int userId = Integer.parseInt(doctorId);
        QcresultDetail qcresultDetail
                = qcresultDetailServiceImpl.getOne(
                new QueryWrapper<QcresultDetail>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .eq("behospital_code", qcRuleWarnVO.getBehospitalCode())
                        .eq("msg", qcRuleWarnVO.getMsg()));
        if (null == qcresultDetail) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "未找到该规则！");
        }

        QcCasesEntry qcCasesEntry = qcCasesEntryFacade.getOne(new QueryWrapper<QcCasesEntry>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id", qcresultDetail.getCasesEntryId()));

        //规则提醒页面模式
        String url = readProperties.getRuleWarnQcUrl() + "?behospitalCode=" + qcRuleWarnVO.getBehospitalCode();
        QcRuleWarn qcRuleWarn = new QcRuleWarn();
        qcRuleWarn.setHospitalId(qcresultDetail.getHospitalId());
        qcRuleWarn.setQcresultInfoId(qcresultDetail.getQcresultInfoId());
        qcRuleWarn.setBehospitalCode(qcresultDetail.getBehospitalCode());
        qcRuleWarn.setFileCode(behospitalInfo.getFileCode());
        qcRuleWarn.setName(behospitalInfo.getName());
        qcRuleWarn.setUserId(userId);
        qcRuleWarn.setWardName(behospitalInfo.getWardName());//病区
        qcRuleWarn.setDeptName(behospitalInfo.getBehDeptName());//科室
        qcRuleWarn.setDoctorName(behospitalInfo.getDoctorName());//主治医生
        qcRuleWarn.setBehospitalDate(behospitalInfo.getBehospitalDate());//入院时间
        qcRuleWarn.setLeaveHospitalDate(behospitalInfo.getLeaveHospitalDate());//出院时间
        qcRuleWarn.setCasesId(qcresultDetail.getCasesId());
        qcRuleWarn.setModelName(ModeIdEnum.getName((qcCasesEntry.getModeId()).intValue()));
        qcRuleWarn.setCasesScore(qcresultDetail.getCasesScore());
        qcRuleWarn.setCasesEntryId(qcresultDetail.getCasesEntryId());
        qcRuleWarn.setScore(qcresultDetail.getScore());
        qcRuleWarn.setMsg(qcresultDetail.getMsg());
        qcRuleWarn.setInfo(qcresultDetail.getInfo());
        qcRuleWarn.setUrl(url);
        qcRuleWarn.setIsReject(qcresultDetail.getIsReject());
        qcRuleWarn.setIsDeleted(IsDeleteEnum.N.getKey());
        qcRuleWarn.setGmtCreate(now);
        qcRuleWarn.setCreator(userId + "");
        boolean flag = qcRuleWarnServiceImpl.save(qcRuleWarn);

        if (flag) {
//            qcresultDetailServiceImpl.update(new UpdateWrapper<QcresultDetail>()
//                    .eq("is_deleted", IsDeleteEnum.N.getKey())
//                    .eq("hospital_id", hospitalId)
//                    .eq("behospital_code", qcRuleWarnVO.getBehospitalCode())
//                    .eq("cases_entry_id", qcresultDetail.getCasesEntryId())
//                    .set("grade_type", 2)
//                    .set("opt_type", 2)
//                    .set("is_deleted", IsDeleteEnum.Y.getKey())
//                    .set("modifier", userId.toString())
//                    .set("gmt_modified", now));
            String sql = "INSERT INTO JKCDSS.JKCDSS_RULE_WARN (ID, USER_ID, BEHOSPITAL_CODE, STATE, URL, GMT_CREATE, GMT_MODIFIED, CREATOR, MODIFIER, REMARK, MSG) " +
                    "VALUES (" + new Date().getTime() + ", " + userId + ", '" + qcRuleWarnVO.getBehospitalCode() + "', 0, '" + url + "', SYSDATE, SYSDATE, 'LT', 'LT', 'NULL', '" + qcRuleWarnVO.getMsg() + "')";
            System.out.println("插入sql语句为--------------------------:" + sql);
            tzDBConn.setRule(sql);
        }

        return flag;
    }

    /**
     * 医生工作站查看规则条目
     *
     * @param behospitalCodeVO
     * @return QcRuleWarnDTO
     */
    public QcRuleWarnDTO checkRule(RecordContentVO behospitalCodeVO) {
        QcRuleWarnDTO qcRuleWarnDTO = new QcRuleWarnDTO();
        // 获取规则条目信息
        List<QcRuleWarn> qcRuleWarns
                = qcRuleWarnServiceImpl.list(
                new QueryWrapper<QcRuleWarn>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", "14")
                        .eq("behospital_code", behospitalCodeVO.getBehospitalCode()));
        if (qcRuleWarns.size() == 0) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "病历不存在错误信息！");
        }
        qcRuleWarnDTO.setFileCode(qcRuleWarns.get(0).getFileCode());
        qcRuleWarnDTO.setName(qcRuleWarns.get(0).getName());
        qcRuleWarnDTO.setWardName(qcRuleWarns.get(0).getWardName());//病区
        qcRuleWarnDTO.setDeptName(qcRuleWarns.get(0).getDeptName());//科室
        qcRuleWarnDTO.setDoctorName(qcRuleWarns.get(0).getDoctorName());//主治医生
        qcRuleWarnDTO.setSendDate(qcRuleWarns.get(0).getGmtCreate());//发送时间
        qcRuleWarnDTO.setBehospitalDate(qcRuleWarns.get(0).getBehospitalDate());//入院时间
        qcRuleWarnDTO.setLeaveHospitalDate(qcRuleWarns.get(0).getLeaveHospitalDate());//出院时间
        BigDecimal dBigDecimal = new BigDecimal(0);//扣分
        BigDecimal resPr = new BigDecimal(100);
        String level = null;
        List<RuleMsgDTO> msgDTOList = new ArrayList<>();
        for (QcRuleWarn qcRuleWarn : qcRuleWarns) {
            dBigDecimal = dBigDecimal.add(qcRuleWarn.getScore());
            RuleMsgDTO msgDTO = new RuleMsgDTO();
            msgDTO.setModelName(qcRuleWarn.getModelName());
            msgDTO.setMsg(qcRuleWarn.getMsg());
            msgDTO.setInfo(qcRuleWarn.getInfo());
            msgDTO.setScore(qcRuleWarn.getScore());
            msgDTOList.add(msgDTO);
        }
        if (dBigDecimal.compareTo(new BigDecimal(10)) < 1) {
            level = "甲";
        } else if (dBigDecimal.compareTo(new BigDecimal(20)) < 1) {
            level = "乙";
        } else {
            level = "丙";
        }
        qcRuleWarnDTO.setScoreRes(resPr.subtract(dBigDecimal));// 得分
        qcRuleWarnDTO.setLevel(level);// 等级
        qcRuleWarnDTO.setNum(Long.valueOf(qcRuleWarns.size()));// 缺陷总数
        qcRuleWarnDTO.setNumScore(dBigDecimal);// 缺陷总扣分
        qcRuleWarnDTO.setMsgDTOList(msgDTOList);

        try {
            String sql = "UPDATE JKCDSS_RULE_WARN SET STATE = 1 WHERE BEHOSPITAL_CODE='" + behospitalCodeVO.getBehospitalCode() + "'";
            tzDBConn.upRule(sql);
        } catch (Exception e) {
            throw new CommonException(CommonErrorCode.UPDATE_INFO_FAIL, "oracle数据插入失败！");
        }

        return qcRuleWarnDTO;

    }

    /**
     * 医生工作站查看规则条目
     *
     * @param behospitalCodeVO
     * @return QcRuleWarnDTO
     */
    public Boolean upState(RecordContentVO behospitalCodeVO) {

        try {
            String sql = "UPDATE JKCDSS_RULE_WARN SET STATE = 2 WHERE BEHOSPITAL_CODE='" + behospitalCodeVO.getBehospitalCode() + "'";
            tzDBConn.upRule(sql);
        } catch (Exception e) {
            throw new CommonException(CommonErrorCode.UPDATE_INFO_FAIL, "oracle数据插入失败！");
        }

        return true;

    }

    /**
     * 删除中间表信息
     *
     * @param behospitalCodeVO
     * @return QcRuleWarnDTO
     */
    public Boolean delState(RecordContentVO behospitalCodeVO) {

        try {
            String sql = "DELETE FROM JKCDSS_RULE_WARN WHERE BEHOSPITAL_CODE='" + behospitalCodeVO.getBehospitalCode() + "'";
            tzDBConn.upRule(sql);
        } catch (Exception e) {
            throw new CommonException(CommonErrorCode.UPDATE_INFO_FAIL, "oracle数据删除失败！");
        }

        return true;

    }


    /**
     * 修改评分结果信息
     *
     * @param qcresultVO 修改评分结果信息
     * @return 评分的结果
     */
    public AnalyzeDTO changeQcResult(QcresultVO qcresultVO) {
        //入参验证
        if (StringUtil.isBlank(qcresultVO.getBehospitalCode())) {
            throw new CommonException(CommonErrorCode.PARAM_IS_NULL, "病历id不能为空！");
        }
        if (null == qcresultVO.getOptResultAlgVO()) {
            throw new CommonException(CommonErrorCode.PARAM_IS_NULL, "操作条目不能为空！");
        }

        Long hospitalId = Long.valueOf(SysUserUtils.getCurrentHospitalID());
        //验证病历的存在性
        List<BehospitalInfo> behospitalInfos
                = behospitalInfoFacade.list(
                new QueryWrapper<BehospitalInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .eq("behospital_code", qcresultVO.getBehospitalCode()));
        if (behospitalInfos.size() != 1) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "该医院下该病历号不存在！");
        }
        //验证是否评估过
        QcresultInfo qcresultInfo
                = this.getOne(
                new QueryWrapper<QcresultInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .eq("behospital_code", qcresultVO.getBehospitalCode()), false);
        if (null == qcresultInfo) {
            throw new CommonException(CommonErrorCode.NOT_EXISTS, "该病历尚未评分，请先评分！");
        }
        //查询质控评分明细信息
        qcresultVO.setHospitalId(hospitalId);
        List<QcresultDetail> qcresultDetails
                = qcresultDetailServiceImpl.list(
                new QueryWrapper<QcresultDetail>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", hospitalId)
                        .eq("behospital_code", qcresultVO.getBehospitalCode()));

        //评分
        AlgorithmVO algorithmVO = new AlgorithmVO();
        List<QcResultAlgVO> qcResultAlgVOList
                = BeanUtil.listCopyTo(qcresultDetails, QcResultAlgVO.class);
        algorithmVO.setType(qcresultVO.getType());
        algorithmVO.setOptResultAlgVO(qcresultVO.getOptResultAlgVO());
        algorithmVO.setQcResultAlgVOList(qcResultAlgVOList);
        algorithmVO.setHospitalId(hospitalId);
        algorithmVO.setBehospitalCode(qcresultVO.getBehospitalCode());
        algorithmVO.setIsPlacefile(behospitalInfos.get(0).getIsPlacefile());
        algorithmVO.setDelStatus(qcresultVO.getDelStatus());
        AlgorithmDTO algorithmDTO = algorithmFacade.getAlgorithmRes(algorithmVO);
        //更新质控评分结果信息
        AnalyzeVO analyzeVO = new AnalyzeVO();
        analyzeVO.setHospitalId(hospitalId);
        analyzeVO.setBehospitalCode(qcresultVO.getBehospitalCode());
        analyzeVO.setDelStatus(qcresultVO.getDelStatus());
        Date date = this.saveQcResult(algorithmDTO, algorithmVO, analyzeVO, null, null, false, qcresultInfo);
        //返回参数组装
        AnalyzeDTO analyzeDTO = new AnalyzeDTO();
        analyzeDTO.setBehospitalCode(qcresultVO.getBehospitalCode());
        analyzeDTO.setIsSuccess(true);
        analyzeDTO.setGradeType(2);
        analyzeDTO.setGradeTypeName("人工");
        analyzeDTO.setScoreRes(algorithmDTO.getScore());
        analyzeDTO.setLevel(algorithmDTO.getLevel());
        analyzeDTO.setGradeTime(date);
        return analyzeDTO;
    }

    /**
     * 保存评分结果信息
     *
     * @param algorithmDTO 评分结果
     * @param algorithmVO  操作的条目
     * @param analyzeVO    病历信息
     * @param pageData     大数据解析出来的页面信息
     * @param menuData     菜单信息
     * @param isTask       是否是任务
     * @return 评分的时间
     */
    public Date saveQcResult(AlgorithmDTO algorithmDTO, AlgorithmVO algorithmVO, AnalyzeVO analyzeVO,
                             String pageData, String menuData, Boolean isTask, QcresultInfo qcresultInfoOld) {
        //更新质控评分结果信息
        Long useId = 0L;
        if (!isTask) {
            try {
                useId = Long.valueOf(SysUserUtils.getCurrentPrincipleID());
            } catch (Exception e) {
                //analyze_run运行质控没有登录认证   所以会获取不到
                useId = 952795279527L;
            }
        }
        //获取上一次人工添加的缺陷
        QcresultInfo qcresultInfoup
                = this.getOne(
                new QueryWrapper<QcresultInfo>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", analyzeVO.getHospitalId())
                        .eq("behospital_code", analyzeVO.getBehospitalCode()), false);
        Date now = DateUtil.now();
        this.update(new UpdateWrapper<QcresultInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", analyzeVO.getHospitalId())
                .eq("behospital_code", analyzeVO.getBehospitalCode())
                .set("is_deleted", IsDeleteEnum.Y.getKey())
                .set("modifier", useId)
                .set("gmt_modified", now));
        //新增记录
        QcresultInfo qcresultInfo = new QcresultInfo();
        if (qcresultInfoOld != null) {
            //新增、删除、修改时的操作
            BeanUtil.copyProperties(qcresultInfoOld, qcresultInfo);
        } else {
            //基本评分是的操作
            qcresultInfo.setHaveHomePage(analyzeVO.getHaveHomePage());
        }
        qcresultInfo.setBehospitalCode(analyzeVO.getBehospitalCode());
        qcresultInfo.setHospitalId(analyzeVO.getHospitalId());
        qcresultInfo.setScoreRes(algorithmDTO.getScore());
        qcresultInfo.setLevel(algorithmDTO.getLevel());
        if (algorithmVO.getType().equals(0)) {
            qcresultInfo.setGradeType(1);
        } else {
            qcresultInfo.setGradeType(2);
        }
        if (StringUtil.isNotBlank(pageData)) {
            qcresultInfo.setPageData(pageData);
        }
        if (StringUtil.isNotBlank(menuData)) {
            qcresultInfo.setMenuData(menuData);
        }

        qcresultInfo.setGmtCreate(now);
        qcresultInfo.setCreator(useId.toString());
        qcresultInfo.setGmtModified(now);
        qcresultInfo.setModifier(useId.toString());
        this.save(qcresultInfo);
        Long newId = qcresultInfo.getId();
        //更新质控评分明细信息
        switch (algorithmVO.getType()) {
            //自动评分
            case 0:
                //删除记录
//                qcresultDetailServiceImpl.remove(new QueryWrapper<QcresultDetail>()
//                        .eq("hospital_id", analyzeVO.getHospitalId())
//                        .eq("behospital_code", analyzeVO.getBehospitalCode()));

                //上一次人工评分条目
                List<QcresultDetail> oldQcresultDetails = null;
                if (qcresultInfoup != null) {
                    oldQcresultDetails = qcresultDetailServiceImpl.list(new QueryWrapper<QcresultDetail>()
                            .eq("hospital_id", analyzeVO.getHospitalId())
                            .eq("qcresult_info_id", qcresultInfoup.getId())
                            .eq("grade_type", "2")
                            .eq("behospital_code", analyzeVO.getBehospitalCode()));
                }

                qcresultDetailServiceImpl.update(new UpdateWrapper<QcresultDetail>()
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", analyzeVO.getHospitalId())
                        .eq("behospital_code", analyzeVO.getBehospitalCode())
                        .set("is_deleted", IsDeleteEnum.Y.getKey())
                        .set("modifier", useId)
                        .set("gmt_modified", now));
                //
                //批量插入新的数据
                List<QcresultDetail> qcresultDetailList = new ArrayList<>();
                if (ListUtil.isNotEmpty(oldQcresultDetails)) {
                    qcresultDetailList.addAll(oldQcresultDetails);
                    qcresultDetailList.forEach(qcresultDetail -> {
                        //原手动添加缺陷绑定新机器评分id
                        qcresultDetail.setQcresultInfoId(newId);
                    });
                }
                List<QcResultAlgVO> qcResultAlgVORes = algorithmVO.getQcResultAlgVOList();
                if (ListUtil.isNotEmpty(qcResultAlgVORes)) {
                    for (QcResultAlgVO qcResultAlgVO : qcResultAlgVORes) {
                        QcresultDetail qcresultDetail = new QcresultDetail();
                        BeanUtil.copyProperties(qcResultAlgVO, qcresultDetail);
                        qcresultDetail.setHospitalId(analyzeVO.getHospitalId());
                        qcresultDetail.setBehospitalCode(analyzeVO.getBehospitalCode());
                        qcresultDetail.setGradeType(1);
                        qcresultDetail.setOptType(1);
                        qcresultDetail.setGmtCreate(now);
                        qcresultDetail.setCreator(useId.toString());
                        qcresultDetail.setGmtModified(now);
                        qcresultDetail.setModifier(useId.toString());
                        qcresultDetail.setInfo(StringUtil.isNotBlank(qcResultAlgVO.getInfo()) ? qcResultAlgVO.getInfo() : "");
                        qcresultDetail.setQcresultInfoId(newId);
                        qcresultDetailList.add(qcresultDetail);
                    }
                    qcresultDetailServiceImpl.saveBatch(qcresultDetailList);
                }
                break;
            case 1:
                //新增条目
                QcresultDetail qcresultDetailAdd = new QcresultDetail();
                BeanUtil.copyProperties(algorithmVO.getOptResultAlgVO(), qcresultDetailAdd);
                qcresultDetailAdd.setGradeType(2);
                qcresultDetailAdd.setOptType(1);
                qcresultDetailAdd.setHospitalId(analyzeVO.getHospitalId());
                qcresultDetailAdd.setBehospitalCode(analyzeVO.getBehospitalCode());
                qcresultDetailAdd.setGmtCreate(now);
                qcresultDetailAdd.setCreator(useId.toString());
                qcresultDetailAdd.setGmtModified(now);
                qcresultDetailAdd.setModifier(useId.toString());
                qcresultDetailAdd.setQcresultInfoId(newId);
                qcresultDetailServiceImpl.save(qcresultDetailAdd);
                break;
            case 2:
                //删除条目
                qcresultDetailServiceImpl.remove(new QueryWrapper<QcresultDetail>()
                        .eq("id", algorithmVO.getOptResultAlgVO().getId())
                        .eq("hospital_id", analyzeVO.getHospitalId())
                        .eq("behospital_code", analyzeVO.getBehospitalCode())
                );
                break;
            case 3:
                //修改条目
                qcresultDetailServiceImpl.update(new UpdateWrapper<QcresultDetail>()
                        .eq("id", algorithmVO.getOptResultAlgVO().getId())
                        .eq("is_deleted", IsDeleteEnum.N.getKey())
                        .eq("hospital_id", analyzeVO.getHospitalId())
                        .eq("behospital_code", analyzeVO.getBehospitalCode())
                        .set("msg", algorithmVO.getOptResultAlgVO().getMsg())
                        .set("score", algorithmVO.getOptResultAlgVO().getScore())
                        .set("opt_type", 3)
                        .set("grade_type", 2)
                        .set("modifier", useId)
                        .set("qcresult_info_id", newId)
                        .set("gmt_modified", now)
                        .set("explain_info", algorithmVO.getOptResultAlgVO().getExplainInfo())
                );
                break;
            case 4:
                //获取病历核查人员id，该操作只能是核查员操作
//                Long checkId = medCheckInfoFacade.getOne(new QueryWrapper<MedCheckInfo>()
//                        .eq("is_deleted", IsDeleteEnum.N.getKey())
//                        .eq("hospital_id", analyzeVO.getHospitalId())
//                        .eq("behospital_code", analyzeVO.getBehospitalCode())).getCheckId();
//                if(checkId==null)
//                {
//                    throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "病历没有分配核查人员");
//                }
//                if(!checkId.equals(useId))
//                {
//                    throw new CommonException(CommonErrorCode.SERVER_IS_ERROR, "当前用户不是分配的核查人员");
//                }
                //逻辑删除质控明细 0删除
                if (analyzeVO.getDelStatus() == 0) {
                    qcresultDetailServiceImpl.update(new UpdateWrapper<QcresultDetail>()
                            .eq("id", algorithmVO.getOptResultAlgVO().getId())
                            .eq("is_deleted", IsDeleteEnum.N.getKey())
                            .eq("hospital_id", analyzeVO.getHospitalId())
                            .eq("behospital_code", analyzeVO.getBehospitalCode())
                            .set("is_deleted", IsDeleteEnum.Y.getKey())
                            .set("grade_type", 2)
                            .set("opt_type", 2)
                            .set("qcresult_info_id", newId)
                            .set("modifier", useId)
                            .set("gmt_modified", now)
                    );
                }
                //1恢复
                else if (analyzeVO.getDelStatus() == 1) {
                    //该条目是机器插入条目
                    qcresultDetailServiceImpl.update(new UpdateWrapper<QcresultDetail>()
                            .eq("id", algorithmVO.getOptResultAlgVO().getId())
                            .eq("is_deleted", IsDeleteEnum.Y.getKey())
                            .eq("hospital_id", analyzeVO.getHospitalId())
                            .eq("behospital_code", analyzeVO.getBehospitalCode())
                            .set("is_deleted", IsDeleteEnum.N.getKey())
                            .set("grade_type", 2)
                            .set("opt_type", 1)
                            .set("qcresult_info_id", newId)
                            .set("modifier", useId)
                            .set("remark", null)
                            .set("gmt_modified", now)
                    );
                } else {
                    throw new CommonException(CommonErrorCode.PARAM_IS_ERROR, "delStatus参数错误");
                }
                break;
            default:
                /* DO NOTHING */
                break;
        }

        //如果不是自动评分（是新增修改删除条目）修改评分主表id
        if (algorithmVO.getType() != 0) {
            //修改上一次人工条目 评分主表id
            if (qcresultInfoup != null && qcresultInfoup.getId() != null) {
                qcresultDetailServiceImpl.update(new UpdateWrapper<QcresultDetail>()
                        .eq("qcresult_info_id", qcresultInfoup.getId())
                        .eq("hospital_id", analyzeVO.getHospitalId())
                        .eq("grade_type", 2)
                        .eq("behospital_code", analyzeVO.getBehospitalCode())
                        .set("qcresult_info_id", newId)
                        .set("modifier", useId)
                        .set("gmt_modified", now)
                );
            }
            //未删除的 评分主表id
            qcresultDetailServiceImpl.update(new UpdateWrapper<QcresultDetail>()
                    .eq("is_deleted", IsDeleteEnum.N.getKey())
                    .eq("hospital_id", analyzeVO.getHospitalId())
                    .eq("behospital_code", analyzeVO.getBehospitalCode())
                    .set("qcresult_info_id", newId)
                    .set("modifier", useId)
                    .set("gmt_modified", now)
            );
        }


        //质控模块评分数据
        //统一为长兴的算法
        //逻辑删除数据
        medQcresultCasesService.update(new UpdateWrapper<MedQcresultCases>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", analyzeVO.getHospitalId())
                .eq("behospital_code", analyzeVO.getBehospitalCode())
                .set("is_deleted", IsDeleteEnum.Y.getKey())
                .set("modifier", useId)
                .set("gmt_modified", now));
        //批量插入新的数据
        List<MedQcresultCases> medQcresultCasesList = new ArrayList<>();
        List<MedQcresultCasesVO> medQcresultCasesVOList = algorithmVO.getMedQcresultCasesVOList();
        if (ListUtil.isNotEmpty(medQcresultCasesVOList)) {
            for (MedQcresultCasesVO medQcresultCasesVO : medQcresultCasesVOList) {
                MedQcresultCases medQcresultCases = new MedQcresultCases();
                BeanUtil.copyProperties(medQcresultCasesVO, medQcresultCases);
                medQcresultCases.setGmtCreate(now);
                medQcresultCases.setCreator(useId.toString());
                medQcresultCases.setGmtModified(now);
                medQcresultCases.setModifier(useId.toString());
                medQcresultCases.setQcresultInfoId(newId);
                medQcresultCasesList.add(medQcresultCases);
            }
            medQcresultCasesService.saveBatch(medQcresultCasesList);
        }
        return now;
    }


    /**
     * 获取评分主表信息
     *
     * @param getDetailVO
     * @return
     */
    public QcResultDTO getByBehospitalCode(GetDetailVO getDetailVO) {
        QcResultDTO res = new QcResultDTO();
        QcresultInfo qcresultInfo = this.getOne(new QueryWrapper<QcresultInfo>()
                .eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("hospital_id", getDetailVO.getHospitalId())
                .eq("behospital_code", getDetailVO.getBehospitalCode()), false
        );
        if (qcresultInfo != null) {
            BeanUtil.copyProperties(qcresultInfo, res);
        } else {
            return null;
        }
        return res;
    }

    /**
     * 获取病历第一次评分和质控缺陷
     * @param qcFirstAnalyzeVO
     * @return
     */
    public QcFirstAnalyzeDTO getQcFirstAnalyze(QcFirstAnalyzeVO qcFirstAnalyzeVO) {

        //1.根据医院id和病历号查询qcresultInfo表
        QcresultInfo qcresultInfo = this.lambdaQuery()
                .eq(QcresultInfo::getHospitalId, qcFirstAnalyzeVO.getHospitalId())
                .like(QcresultInfo::getBehospitalCode, qcFirstAnalyzeVO.getBehospitalCode())
                .orderByAsc(QcresultInfo::getGmtCreate)
                .last("LIMIT 1")
                .one();
        //2.判断病历等级是否为为空
        if (qcresultInfo == null) {
            return new QcFirstAnalyzeDTO();
        }

        QcFirstAnalyzeDTO dto = new QcFirstAnalyzeDTO();
        dto.setLevel(qcresultInfo.getLevel());
        dto.setScoreRes(qcresultInfo.getScoreRes());

        // 3. 查询第一次质控缺陷条目
        List<String> msgs = qcresultDetailFacade.lambdaQuery()
                .eq(QcresultDetail::getBehospitalCode, qcresultInfo.getBehospitalCode())
                .eq(QcresultDetail::getQcresultInfoId, qcresultInfo.getId())
                .list()
                .stream()
                .map(QcresultDetail::getMsg)
                .collect(Collectors.toList());
        dto.setMsg(msgs);

        return dto;
    }
}


